def start():
    print("It is recommended to copy mainApp.py and run it instead of importing the library.")
    import pychatapp.mainApp
